==> ZenTaoPMS.max2.4.php5.3_5.6.zip: zentaopms/module/action/ext/model/class/oa.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPoJtQLimNrATSqByUBdkyeB9dG6FTbN40nHb/GaP+zDtSJqJzWfngS6wrxc8R+KsjWaBKcf1
QJB/q8uaipH6TrMwmqHKxktnwzgtv952Z/NzCRpuTbYcURrdz3GGiQvRavORSOxtVyNsA6rxqWnW
JAg9Bwqh8RjRD8bI3A4jZQZgTF42LE5JwrpWa72NdIs0d8Bi9oqbfSZ7E4fpMVqFgkCsX19A6+eI
0LECaS6yk485rwyxJ+Tz9utkD71UV/mc6MNN9C/uzsBUccpTgg0tNvF/xq+Hv+E4bhTlgOVEiKti
tCowgtODQO0E+wQjDbWtmLbFWl8nI/6cIAcGREhX0NEA8RQfyYijkK1GBEKJTG/39O5LcARYMU+m
fe7XZW0FLlkVd+cM1QOxl2Cr3v6ILbP1Hm5XAymW6DpIZpaI6R/jMmjDIpJtsup0V20O83ONSSwo
1DkJNnXYKY8q325/n9M1mJdJnTkOzufjP5pjv9kdTsL0K8q+iXRfbcTJVTRcXPCjaCFQbN7e0pYv
QaxJtQNZQJy4P5ZGcsOgPn3RQOVeLyYuUny0oXfVKftlMMJaqlsSCobLgeZkQyeH2KkYdeuXNiCP
20pXdko06mvcJU28QUNisr1rNrT2KuioYv1eRX12ps2Hvy/QS7z912r49iCcnFc9a1+JxT8uaXIk
93CfYomoWVP1b3hC37u6cjYziGTfSupfqTyv+yQwVTE08f26k69iejyUTyo3QgGPShSSRLYXP+QD
PsobeGhtVevNwdViyg1nDR3BIBMALPicdYt4xkXt3QQVv5+g4L90HnemTOxCVQXkd5ZnZ7qJf7BT
kOiwOYFFRBomDUe/8575W+YTLP70lIIH9fcPYKDVKmoSfakjZ27cR4LQJIhvze7E8KbYJRvQ6LVb
Q87WhcX3PvZ6RcYdbNMPaRtopZ0S22PHVLTSekyEjBAfAoOaM7MkaVdePkZOZ9tPpmMLLCexgDlI
8Py=

==> ZenTaoPMS.max2.7.php5.3_5.6.zip: zentaopms/module/action/ext/model/class/oa.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cP+CMD/rp/8lojAEYtX6XQo2ydHCgMyr7fDLnW6W0OqaJ+l6PT4JJayhJzj30yA1hcSJTc4Jr
gl7hqemM3nYF2JHPa12L/q+J9fa4CAt5wl53Cygly753taoM81reELl2XOGzqmSBTkLxAakSRdP9
FWjmHiogU8juuf64Q07eZun76Lg7/q+RegrdQsx7DyDhgV7aBtVTXC3ICiawjsEgrx5rQYVyMG9R
doEcBKPJ232PRJFs39yo06Bv93LToEm5ORXawWcYN2mpkTdDmqPGNzW6lJ4F5MZDcJblCY47l+jw
f0RdCkPjLlQxNqg3xCt/5UiU9y2D15sZR/oOnNt/ix7yX6wd4TVuwddWwboFpazUjWJdUQUyQAqW
VZDHFW7DxNSpyf8B8k5RcJGJZFMQPkqN3b+56Vv8+0iK/fjJcRXj3wHZb7yNZf6M9a/dWg4xRffo
li/w4URcV/UCf/tBtHOzf0Nl1SnU2qDJP13kR2SL9AgEuw1Rce6Oorm+BK3Gg7jbQNeZVVWSvzEP
NbZvYFPfvQbaqp1aFkca/U6BUlr/f4ADofXJLopk2C2FLHTgcqfM3SBa1yDxuP/rEtc24qCY0qd5
cGacElRHcDqMZVsZ6mK84fCN6xk+uN8HC5Pbdy1V0OgevdG8gpJtGXzae6nFum9sq1rMVvuFH5dF
urDUEyPIBfNovZAD8zXg3LBEO9PmNnV5lceo+NiF+Y40ptYAFKa6liZYGfmkav0RBlel1dP+N2lJ
BgPW0CC6URkDqzQEQL4UJjegGJI9fd02RgKjv3XiMPH3zGAeqpDj7CyCSy773LSVn82MFXeFPvmp
Sck8r5LEMukQzslqQR7rXJZN+DzI66JAh/d7MSsJomcxLK1zY4IeDvAmf/pculcERc5XS4V5Rav7
jK2w3iNV592Jm7oRS0ok10uEbco0zLhX05xlM627Wu8PU1T0a1sPTRasbHPNMvWWCBJiSMbQhSNC
yGy=
